@@ -297,19 +297,19 @@ class RedizConventions(object):
                 "subscribers": self.subscribers_name,
                 "subscriptions": self.subscriptions_name,
                 "history": self.history_name,
-                "messages": self.messages_name,
-                "overall_performance":self.performance_name}
+                "messages": self.messages_name}
 
     def _delay_methods(self):
         return {"delayed": self.delayed_name,
-                "links": self.links_name,
-                "participants": self._sample_owners_name,
-                "cdf": self.cdf_name,
-                "performance":self.performance_name}
+                "links": self.links_name}
 
     def cdf_name(self,name,delay=None):
         return self.CDF + name if delay==None else self.CDF+str(delay)+self.SEP+name
 
+
+
+
+
     # --------------------------------------------------------------------------
     #           Private conventions (names, places, formats, ttls )
     # --------------------------------------------------------------------------
